@@ -1,17 +1,16 @@
 #! /bin/sh
 
-# $OpenBSD: vpnc.sh,v 1.3 2005/05/05 10:54:48 sturm Exp $
+# $OpenBSD: vpnc.sh,v 1.4 2009/01/29 19:07:06 pea Exp $
 
 TUN_IF=tun0
 PHYS_IF=wi0
-PREFIX=/usr/local
 VPNGATEWAY=192.168.0.1
 
 case "$1" in
 start)
 	dhclient ${PHYS_IF}
 	DEFAULTROUTER=`route -n show -inet | grep default | awk '{ print $2 }'`
-	${PREFIX}/sbin/vpnc || exit 1
+	/usr/local/sbin/vpnc || exit 1
 	TUN_IP=`ifconfig ${TUN_IF} | grep netmask | awk '{ print $2 }'`
 	route add -host ${VPNGATEWAY} ${DEFAULTROUTER}
 	route delete default
